package com.ruoyi.business.controller;

import java.util.ArrayList;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import java.util.Arrays;
import java.util.stream.Collectors;

import com.baomidou.mybatisplus.extension.conditions.query.LambdaQueryChainWrapper;
import com.ruoyi.business.domain.ApplyPlan;
import com.ruoyi.business.domain.ApplyPlanLog;
import com.ruoyi.business.domain.Rebot;
import com.ruoyi.business.domain.vo.ListApplyVO;
import com.ruoyi.business.service.IApplyPlanLogService;
import com.ruoyi.business.service.IApplyPlanService;
import com.ruoyi.common.enums.PlanRunStatus;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.business.domain.Apply;
import com.ruoyi.business.service.IApplyService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 应用信息管理Controller
 *
 * @author LiuChengRan
 * @date 2024-06-13
 */
@Api(tags = "应用信息管理接口")
@RestController
@RequestMapping("/business/ctApply")
public class ApplyController extends BaseController {
    @Autowired
    private IApplyService applyService;

    @Autowired
    private IApplyPlanService applyPlanService;

    @Autowired
    private IApplyPlanLogService applyPlanLogService;

    /**
     * 同步应用数据
     */
    @ApiOperation(value = "修改应用实际执行时间", httpMethod = "POST", response = Rebot.class)
    @PostMapping("/updateRunDate")
    public AjaxResult updateRunDate(@RequestBody Apply apply) throws IllegalAccessException {
        return toAjax(applyService.updateRunDate(apply));
    }


    /**
     * 同步应用数据
     */
    @ApiOperation(value = "同步应用数据", httpMethod = "POST", response = Rebot.class)
    @PostMapping("/syn")
    public AjaxResult syn(Apply apply) throws IllegalAccessException {
        applyService.syn(apply);
        return AjaxResult.success();
    }

    /**
     * 查询所有应用列表
     */
    @ApiOperation(value = "查询所有应用列表", httpMethod = "GET", response = Apply.class)
    @GetMapping("/listAll")
    public AjaxResult listAll(Apply apply) {
        List<Apply> list = applyService.listAll(apply);
        return AjaxResult.success(list);
    }


    /**
     * 查询应用信息管理列表
     */
    @ApiOperation(value = "查询应用信息管理列表", httpMethod = "GET", response = Apply.class)
    @GetMapping("/list")
    public TableDataInfo list(Apply apply) {
        // 获取所有计划
        List<ApplyPlan> planList = applyPlanService.lambdaQuery().isNotNull(ApplyPlan::getManualTime)
                .and(e -> e.in(ApplyPlan::getExcType, "0", "1")
                        .eq(ApplyPlan::getTaskStatus, PlanRunStatus.FINISH.getKey()).or().eq(ApplyPlan::getExcType, "2"))
                .list();
        // 只过滤执行计划的id
        List<String> planIdList = planList.stream().filter(e -> "2".equals(e.getExcType())).map(ApplyPlan::getId).collect(Collectors.toList());
        // 获取所有 设置了时间并且是完成状态的计划记录
        LambdaQueryChainWrapper<ApplyPlanLog> qw = applyPlanLogService.lambdaQuery().eq(ApplyPlanLog::getStatus,"0");
        List<ApplyPlanLog> planLogList = null;
        if (planIdList.isEmpty()) {
            planLogList = new ArrayList<>();
        } else {
            planLogList = qw.in(ApplyPlanLog::getPlanId, planIdList).isNotNull(ApplyPlanLog::getUpdateTime).list();
        }
        startPage();
        List<ListApplyVO> list = applyService.list(apply,planList, planLogList );
        return getDataTable(list);
    }

    /**
     * 导出应用信息管理列表
     */
    @ApiOperation(value = "导出应用信息管理列表", httpMethod = "POST")
    @Log(title = "应用信息管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Apply apply) {
        // 获取所有执行成功的计划
        List<ApplyPlan> planList = applyPlanService.lambdaQuery().eq(ApplyPlan::getTaskStatus, PlanRunStatus.FINISH.getKey()).list();
        // 获取所有计划记录
        List<ApplyPlanLog> planLogList = applyPlanLogService.list();
        List<ListApplyVO> list = applyService.list(apply,planList, planLogList);
        ExcelUtil<ListApplyVO> util = new ExcelUtil<ListApplyVO>(ListApplyVO.class);
        util.exportExcel(response, list, "应用信息管理数据");
    }

    /**
     * 获取应用信息管理详细信息
     */
    @ApiOperation(value = "获取应用信息管理详细信息", httpMethod = "GET", response = Apply.class)
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(applyService.getById(id));
    }

    /**
     * 新增应用信息管理
     */
    @ApiOperation(value = "新增应用信息管理", httpMethod = "POST")
    @Log(title = "应用信息管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Apply apply) {
        return toAjax(applyService.save(apply));
    }

    /**
     * 修改应用信息管理
     */
    @ApiOperation(value = "修改应用信息管理", httpMethod = "PUT")
    @Log(title = "应用信息管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Apply apply) {
        return toAjax(applyService.updateById(apply));
    }

    /**
     * 删除应用信息管理
     */
    @ApiOperation(value = "删除应用信息管理", httpMethod = "DELETE")
    @Log(title = "应用信息管理", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(applyService.removeByIds(Arrays.asList(ids)));
    }
}
