package com.ruoyi.business.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import java.util.Arrays;

import com.ruoyi.common.enums.RebotStatus;
import com.ruoyi.common.utils.SecurityUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.business.domain.Rebot;
import com.ruoyi.business.service.IRebotService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 机器人管理Controller
 *
 * @author LiuChengRan
 * @date 2024-06-13
 */
@Api(tags = "机器人管理接口")
@RestController
@RequestMapping("/business/ctRebot")
public class RebotController extends BaseController {
    @Autowired
    private IRebotService rebotService;

    /**
     * 同步机器人数据
     */
    @ApiOperation(value = "同步机器人数据", httpMethod = "POST", response = Rebot.class)
    @PostMapping("/syn")
    public AjaxResult syn(Rebot rebot) throws IllegalAccessException {
        rebotService.syn(rebot);
        return AjaxResult.success();
    }

    /**
     * 查询所有可用（空闲）机器人
     */
    @ApiOperation(value = "查询所有可用（空闲）机器人", httpMethod = "GET", response = Rebot.class)
    @GetMapping("/listAll")
    public AjaxResult listAll(Rebot rebot) {
        rebot.setStatus(RebotStatus.IDLE.getKey());
        List<Rebot> list = rebotService.list(rebot);
        return AjaxResult.success(list);
    }
    /**
     * 查询所有机器人
     */
    @ApiOperation(value = "查询所有机器人", httpMethod = "GET", response = Rebot.class)
    @GetMapping("/listRebotAll")
    public AjaxResult listRebotAll(Rebot rebot) {
        List<Rebot> list = rebotService.list(rebot);
        return AjaxResult.success(list);
    }

    /**
     * 查询机器人管理列表
     */
    @ApiOperation(value = "查询机器人管理列表", httpMethod = "GET", response = Rebot.class)
    @GetMapping("/list")
    public TableDataInfo list(Rebot rebot) {
        startPage();
        List<Rebot> list = rebotService.list(rebot);
        return getDataTable(list);
    }

    /**
     * 导出机器人管理列表
     */
    @ApiOperation(value = "导出机器人管理列表", httpMethod = "POST")
    @Log(title = "机器人管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Rebot rebot) {
        List<Rebot> list = rebotService.list(rebot);
        ExcelUtil<Rebot> util = new ExcelUtil<Rebot>(Rebot.class);
        util.exportExcel(response, list, "机器人管理数据");
    }

    /**
     * 获取机器人管理详细信息
     */
    @ApiOperation(value = "获取机器人管理详细信息", httpMethod = "GET", response = Rebot.class)
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(rebotService.getById(id));
    }

    /**
     * 新增机器人管理
     */
    @ApiOperation(value = "新增机器人管理", httpMethod = "POST")
    @Log(title = "机器人管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Rebot rebot) {
        return toAjax(rebotService.save(rebot));
    }

    /**
     * 修改机器人管理
     */
    @ApiOperation(value = "修改机器人管理", httpMethod = "PUT")
    @Log(title = "机器人管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Rebot rebot) {
        return toAjax(rebotService.updateById(rebot));
    }

    /**
     * 删除机器人管理
     */
    @ApiOperation(value = "删除机器人管理", httpMethod = "DELETE")
    @Log(title = "机器人管理", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(rebotService.removeByIds(Arrays.asList(ids)));
    }
}
